$wnd.rstudio.runAsyncCallback3("function cNi(a){var b;Qwn[b=++Rwn]=cNi;this.a=(Swn[b]=Cxn,a);Rwn=b-1}\nfunction nNi(a){var b;Qwn[b=++Rwn]=nNi;this.a=(Swn[b]=gxn,a);Rwn=b-1}\nfunction eNi(a){var b;Qwn[b=++Rwn]=eNi;this.a=(Swn[b]=rAn,a);Rwn=b-1}\nfunction qxe(a,b){var c,d;Qwn[d=++Rwn]=qxe;for(Swn[d]=UBn,c=0;(Swn[d]=UBn,c)<(Swn[d]=uFn,a.p.a).length;Swn[d]=UBn,c++){if(Fld((Swn[d]=pFn,a).p,c).JP==b){fAe((Swn[d]=gzn,(Swn[d]=mzn,a).s),FNd((Twn=(Swn[d]=mzn,c),Swn[d]=gzn,Twn)));break}}Rwn=d-1}\nfunction bNi(a,b){var c;Qwn[c=++Rwn]=bNi;this.c=(Swn[c]=zyn,a);this.b=(Twn=wwi((Swn[c]=VBn,a).c,f6o,g6o,(Twn=Tfo,Swn[c]=FUn,Twn)),Swn[c]=VBn,Twn).LH();this.a=(Twn=wwi((Swn[c]=Vxn,a).c,h6o,i6o,(Twn=j6o,Swn[c]=IUn,Twn)),Swn[c]=Vxn,Twn).LH();$h((Swn[c]=Cxn,b),new cNi(this),(Twn=(Swn[c]=Gxn,vD)?vD:(vD=new QA),Swn[c]=uRn,Twn));Rwn=c-1}\nfunction _Mi(a){var b,c;Qwn[c=++Rwn]=_Mi;b=aNi((Swn[c]=Dxn,a),'weaving Rnw files',(Swn[c]=nDn,a).b,(Twn=wwi((Swn[c]=Ezn,a).c.c,f6o,g6o,(Twn=Tfo,Swn[c]=FUn,Twn)),Swn[c]=Dxn,Twn));(Swn[c]=dyn,b)||aNi((Swn[c]=lDn,a),'LaTeX typesetting',(Swn[c]=fyn,a).a,(Twn=wwi((Swn[c]=iCn,a).c.c,h6o,i6o,(Twn=j6o,Swn[c]=IUn,Twn)),Swn[c]=lDn,Twn));Rwn=c-1}\nfunction ZMi(a,b,c){var d,e;Qwn[e=++Rwn]=ZMi;Swn[e]=vCn,d=IHi((Swn[e]=rKn,(Swn[e]=vCn,a).b.a));vxe((Swn[e]=cyn,d),(Twn=Wyi(SQg((Swn[e]=$zn,(Swn[e]=Zyn,Vyf(),(Swn[e]=cyn,Uyf)).a))),Swn[e]=cyn,Twn));!(Swn[e]=FBn,!(Swn[e]=hyn,b))&&qxe((Swn[e]=Fxn,d),b);Bxe((Swn[e]=Exn,d),c);qpe((Swn[e]=axn,d),(Twn=true,Swn[e]=jFn,Twn));new bNi((Swn[e]=jyn,a),d);((Swn[e]=xxn,vFf())||!!(Swn[e]=YBn,$wnd).remoteDesktop)&&(Swn[e]=txn,zFf());Rwn=e-1}\nfunction jNi(b){var c,d;Qwn[c=++Rwn]=jNi;try{if((Swn[c]=lxn,b).c<0){d=true;return}(Swn[c]=oBn,!(Swn[c]=byn,b).a.a)&&(Swn[c]=Axn,(Swn[c]=Axn,b).a.a=cUi((Swn[c]=qKn,b.a.b.a)));switch((Swn[c]=Bxn,b).c){case 1:ZMi((Swn[c]=Uzn,b).a.a,null,(Twn=true,Swn[c]=Szn,Twn));break;case 2:ZMi((Swn[c]=hyn,b).a.a,b.b[0],mMd(b.b[1]));}}catch(a){a=v2c(a);Rwn=(Swn[c]=vyn,c);throw w2c(a)}finally{(Swn[c]=Gxn,b).c<=0&&b.b[0]!=null&&b.b[0].zm();d&&(Rwn=c-1)}Rwn=c-1}\nfunction aNi(a,b,c,d){var e;Qwn[e=++Rwn]=aNi;if(UJ((Swn[e]=XEn,c))!==UJ(d.LH())&&UJ((Swn[e]=dDn,d).Gq())!==UJ(d.LH())){c5d(2,'Project Option Unchanged','You changed the global option for '+(Swn[e]=pAn,b)+Ido+(Swn[e]=qAn,d).LH()+', however the current project is '+'still configured to use '+(Swn[e]=_Bn,d).Gq()+'.\\n\\n'+'Do you want to edit the options for the current '+'project as well?',new eNi((Swn[e]=rAn,a)),(Twn=true,Swn[e]=Vzn,Twn));Rwn=e-1;return true}else{Rwn=e-1;return false}Rwn=e-1}\nY2c(2847,1,{},bNi);var aUb=GMd(2847);Y2c(2848,1,_ao,cNi);_.Gn=function dNi(a){var b;Qwn[b=++Rwn]=dNi;_Mi((Swn[b]=Cxn,this.a));Rwn=b-1};var $Tb=GMd(2848);Y2c(2849,1,Feo,eNi);_.zm=function fNi(){var a;Qwn[a=++Rwn]=fNi;Pae((Twn=(Swn[a]='6341',(Swn[a]=rAn,this.a).c.a.Ug),Swn[a]=rAn,Twn));Rwn=a-1};var _Tb=GMd(2849);Y2c(628,1,HLo);_.xm=function mNi(){var a;Qwn[a=++Rwn]=mNi;jNi((Swn[a]=kxn,(new nNi((Twn=this,Swn[a]=gxn,Twn))).a));Rwn=a-1};Y2c(2903,1,feo,nNi);_.zm=function oNi(){var a;Qwn[a=++Rwn]=oNi;jNi((Swn[a]=kxn,this.a));Rwn=a-1};var bUb=GMd(2903);Pwn(Kl)(3);\n//# sourceURL=rstudio-3.js\n")
