$wnd.rstudio.runAsyncCallback16("function wek(a){var b;o7m[b=++p7m]=wek;this.a=(q7m[b]=S7m,a);p7m=b-1}\nfunction Vck(a,b){var c;o7m[c=++p7m]=Vck;this.a=(q7m[c]=Vkn,a);this.b=b;gie.call(this);p7m=c-1}\nfunction vck(a){var b,c;o7m[c=++p7m]=vck;b=IHf(new JHf(0,(r7m='Closing Presentation...',q7m[c]=yon,r7m)));Szh((q7m[c]=Vkn,a).j,new Vck(a,b));p7m=c-1}\nfunction Szh(a,b){var c;o7m[c=++p7m]=Szh;MEh((q7m[c]=whp,a),svo,'close_presentation_pane',(q7m[c]=nIo,new qE),(r7m=(q7m[c]=whp,b),q7m[c]=oIo,r7m));p7m=c-1}\nfunction yck(a,b){var c;o7m[c=++p7m]=yck;(q7m[c]=cln,a).a=b;Ldk((q7m[c]=Ydn,a).n,uck(a,(r7m=null,q7m[c]=Inn,r7m)),(r7m=(q7m[c]=s7m,(q7m[c]=Ydn,a).a.file_path),q7m[c]=Ydn,r7m));p7m=c-1}\nfunction Gck(a){var b;o7m[b=++p7m]=Gck;x4e('Opening Presentation...',(q7m[b]=Jfn,pwd()));Lof((q7m[b]=iLn,(q7m[b]=G8m,a).c),new Gqf,(r7m=false,q7m[b]=O7m,r7m));p7m=b-1}\nfunction Ack(a,b){var c;o7m[c=++p7m]=Ack;(q7m[c]=z7m,(q7m[c]=Yan,b).slide_index)==0&&Lti((q7m[c]=D8m,a).n);q7m[c]=cln,(q7m[c]=S8m,a).a=b;Ldk((q7m[c]=Ydn,(q7m[c]=S8m,a).n),uck((q7m[c]=S8m,a),(r7m=null,q7m[c]=Inn,r7m)),(r7m=(q7m[c]=s7m,(q7m[c]=Ydn,(q7m[c]=S8m,a).a).file_path),q7m[c]=Ydn,r7m));p7m=c-1}\nfunction Fck(a){var b,c;o7m[c=++p7m]=Fck;(q7m[c]=q8m,(q7m[c]=Scn,a).G).zF();!(q7m[c]=Xbn,!(q7m[c]=Ckn,a).a)&&(q7m[c]=A7m,(q7m[c]=t7m,a).a.active)&&(b=gfe((r7m=(q7m[c]=Sin,ph((r7m=(q7m[c]=Wbn,(q7m[c]=udn,a).n.d),q7m[c]=m8m,r7m)).contentWindow),q7m[c]=Wbn,r7m)),(q7m[c]=udn,!(!IId(fRn,(q7m[c]=Kcn,b))&&!IId('javascript:void(0)',(q7m[c]=Jfn,b)))))&&yck((q7m[c]=M8m,a),a.a);p7m=c-1}\nfunction sek(b){var c,d,e,f;o7m[e=++p7m]=sek;try{if((q7m[e]=x7m,b).c<0){f=true;return}if(q7m[e]=Fbn,!(q7m[e]=z8m,b).a.a){q7m[e]=C7m,(q7m[e]=C7m,b).a.a=gfk((q7m[e]=p9m,b.a.b.a));toi((q7m[e]=N8m,b).a,b.a.a)}switch((q7m[e]=B9m,b).c){case 1:vck((d=(q7m[e]=E7m,b).a.a,b.b[0],d));break;case 2:Ack((q7m[e]=i8m,b).a.a,b.b[0]);break;case 3:(q7m[e]=vfn,(q7m[e]=Q7m,b).a.a.G).xF();break;case 4:(q7m[e]=pbn,(q7m[e]=U9m,b).a.a.G).yF();break;case 5:Fck((q7m[e]=V9m,b).a.a);break;case 6:Gck((c=(q7m[e]=Ccn,b).a.a,b.b[0],c));break;case 7:(q7m[e]=n8m,(q7m[e]=xfn,b).a.a.G).AF();}}catch(a){a=d$c(a);p7m=(q7m[e]=J8m,e);throw e$c(a)}finally{(q7m[e]=cbn,b).c<=0&&b.b[0]!=null&&b.b[0].zm();f&&(p7m=e-1)}p7m=e-1}\nG$c(6861,31,{},Vck);_.yt=function Xck(a){var b,c;o7m[c=++p7m]=Xck;Lof((q7m[c]=iLn,(q7m[c]=Pdn,(q7m[c]=Zmn,b=this,a,b).a).c),new Gqf,(r7m=false,q7m[c]=O7m,r7m));p7m=c-1};_.xt=function Wck(a){var b;o7m[b=++p7m]=Wck;$Gf((q7m[b]=Tmn,this.b),(r7m=(q7m[b]=O8m,a.a)?(q7m[b]=B7m,(q7m[b]=E7m,(q7m[b]=Tmn,a).a).c):(q7m[b]=h8m,(q7m[b]=Tmn,a).d),q7m[b]=Tmn,r7m));p7m=b-1};var Vhc=YGd(6861);G$c(453,1,Lio);_.xm=function vek(){var a;o7m[a=++p7m]=vek;sek((q7m[a]=U7m,(new wek((r7m=this,q7m[a]=S7m,r7m))).a));p7m=a-1};G$c(6403,1,uQn,wek);_.zm=function xek(){var a;o7m[a=++p7m]=xek;sek((q7m[a]=U7m,this.a));p7m=a-1};var sic=YGd(6403);n7m(Il)(16);\n//# sourceURL=rstudio-16.js\n")
