/*
 * rstudio.css
 *
 * Copyright (C) 2021 by RStudio, PBC
 *
 * This program is licensed to you under the terms of version 3 of the
 * GNU Affero General Public License. This program is distributed WITHOUT
 * ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THOSE OF NON-INFRINGEMENT,
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. Please refer to the
 * AGPL (http://www.gnu.org/licenses/agpl-3.0.txt) for more details.
 *
 */

body {
  background-color: #fff;
}

@media (prefers-color-scheme: dark) {
  body {
    background-color: #000;
    color: #fff;
  }

  a, a:visited {
    color: #bb86fc;
  }
}

body, td {
  font-family: Lucida Grande, Lucida Sans Unicode, Helvetica, sans-serif;
  font-size: 11pt;
}

#banner {
  background-color: #e0e2e5;
  margin: 30px 20px 70px 20px;
  padding: 8px;
  -moz-border-radius: 5px;
  -webkit-border-radius: 5px;
  overflow: hidden;
}

@media (prefers-color-scheme: dark) {
  #banner {
    background-color: #202225;
  }
}

#logo {
  width: 50%;
  float: left;
}
#licensed-to {
  width: 50%;
  float: right;
  margin-top: 0.5em;
  text-align: right;
}
#license-prefix {
  opacity: 0.6;
  font-weight: normal;
}
#border {
  width: 300px;
  padding: 15px;
  background-color: #f7f8f9;
}
@media (prefers-color-scheme: dark) {
  #border {
    background-color: #202225;
    color: #fff;
  }
}
#image {
  margin-right: -18px;
}

#iewarn {
  color: #888;
  width: 480px;
  margin-left: auto;
  margin-right: auto;
  text-align: center;
}

#caption {
  text-align: left;
  border-bottom: 4px solid #e0e2e5;
  padding-bottom: 8px;
  margin-bottom: 8px;
  margin-right: 10px;
  font-size: 16px;
  font-weight: normal;
  width: 250px;
}

#detail {
  color: #aaa;
  margin-top: 8px;
  margin-right: 10px;
}

a img {
  border: none;
}

#login-html {
  margin: 30px 20px 70px 20px;
  padding: 8px;
}

#skipnav a {
    position: absolute;
    clip: rect(0 0 0 0);
    border: 0;
    height: 1px; margin: -1px;
    overflow: hidden;
    padding: 0;
    width: 1px;
    white-space: nowrap;
}

#skipnav a:focus {
    clip:auto;
    left:0;
    top:0;
    width:100%;
    height:auto;
    margin:0;
    padding:10px 0;
    background:#fdf6e7;
    border:2px solid #990000;
    border-left:none;
    border-right:none;
    text-align:center;
    font-weight:bold;
    color:#990000;
}

.visuallyhidden {
    position: absolute;
    clip: rect(0 0 0 0);
    border: 0;
    width: 1px;
    height: 1px;
    margin: -1px;
    overflow: hidden;
    padding: 0;
}

