$wnd.rstudio.runAsyncCallback7("function hhk(a){this.a=a}\nfunction rgk(a,b){this.a=a;this.b=b}\nfunction ngk(a,b){b==null?Cbe(a,UWo):Cbe(a,b)}\nfunction Cgk(a,b){Zh(a.d,new eme(false));tgk(a.d,b,0)}\nfunction EZh(a,b){d_h(a,Tdo,'markers_tab_closed',new nH,b)}\nfunction ogk(a,b){var c,d,e,f,g,h,i;d=a.p;Jwd(d.n);for(g=b,h=0,i=g.length;h<i;++h){f=g[h];c=new rgk(a,f);e=new t4c(r4c(new s4c,f).a.a);Okf(d,new Qxd(e,c))}}\nfunction tgk(a,b,c){var d;Ryg(a.b);ngk(a.c,null);ogk(a.c,eJ($I(TX,1),twn,2,6,[]));if(b.markers){d=b.markers;Vyg(a.b,null,d.base_path,d.markers,c,false);ogk(a.c,Cte(b.names));ngk(a.c,d.name)}}\nfunction Bgk(a,b){var c,d,e,f,g;g=b.a.markers_state;if(g.markers){Zh(a.d,new eme(true));tgk(a.d,b.a.markers_state,b.a.auto_select);e=g.markers;if(e){d=e.markers;if(d.length>0){f=null;c=b.a.auto_select;c==1?(f=d[0]):c==2&&(f=Dyg(d));!!f&&Tfg(a.b,(coe(),uoe(f.path,false,-1,0)),M3d(f.line,f.column),false)}}}else{Zh(a.d,new Zle)}}\nfunction dhk(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=qhk(a.a.b.a);NKi(a.a,a.a.a)}switch(a.c){case 1:Agk(a.a.a);break;case 2:a.a.a.G.PH();break;case 3:a.a.a.G.QH();break;case 4:EZh(a.a.a.c,new kBf);break;case 5:Bgk(a.a.a,a.b[0]);break;case 6:a.a.a.G.RH();break;case 7:a.a.a.G.SH();break;case 8:Cgk(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nS2c(7560,1,lyn,rgk);_.zm=function sgk(){VD(this.a,this.b)};var sgc=AMd(7560);S2c(424,1,n6n);_.xm=function ghk(){dhk((new hhk(this)).a)};S2c(6248,1,UEn,hhk);_.zm=function ihk(){dhk(this.a)};var Fgc=AMd(6248);Jvn(Il)(7);\n//# sourceURL=rstudio-7.js\n")
