$wnd.rstudio.runAsyncCallback15("function JBi(){}\nfunction HBi(a){this.a=a}\nfunction MBi(a){this.a=a}\nfunction OBi(a){this.a=a}\nfunction OCi(a){this.a=a}\nfunction $Ai(a){this.a=a}\nfunction wRf(a){this.a=a}\nfunction DAi(a){PAi(a,new MBi(a))}\nfunction IAi(a){UPf(a.b,new OBi(a))}\nfunction HAi(a){Xjk(a.k,new HBi(a),new JBi,uFn)}\nfunction KAi(a){Xjk(a.k,new BBi(a,null),new DBi,NMn)}\nfunction LAi(a,b){gpf(a.d,new jTi(b,true),false)}\nfunction dQf(a,b){(LWd(b),b)&&NAi(a.a,ZFo,'')}\nfunction aBi(a,b){this.a=a;this.b=b;Ekf.call(this)}\nfunction LBi(a,b){LAi(a.a,'devtools::load_all(\"'+b+'\")')}\nfunction NBh(a,b){dGh(a,iPn,'devtools_load_all_path',new vE,b)}\nfunction PAi(a,b){a.c!=null?LBi(b,a.c):NBh(a.i,new aBi(a,b))}\nfunction JAi(a){a.H.MF();Fm((ym(),xm),new $Ai(a))}\nfunction YAi(){GHf.call(this,'Terminating Build...')}\nfunction UPf(a,b){GPf(a,YFo,YFo,XRf(a.g.b.package_dependencies,'roxygen'),tPf(a,'roxygen'),false,new wRf(b))}\nfunction AAi(a,b){var c,d;IJf(a.p.e,null);d=b.outputs;for(c=0;c<d.length;c++)Xzi(a.p,d[c]);b.errors.length>0&&Wzi(a.p,b.errors_base_dir,b.errors,false,0,true,b.type);b.running?M5d(a.a.Cj,true,false):HJf(a.p.e);jMe(a.p.e.c.c)}\nfunction KCi(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=nDi(a.a.b.a);Mpi(a.a,a.a.a)}switch(a.c){case 1:AAi(a.a.a,a.b[0]);break;case 2:a.a.a.H.KF();break;case 3:a.a.a.H.LF();break;case 4:NAi(a.a.a,Eno,'');break;case 5:NAi(a.a.a,'build-binary-package','');break;case 6:NAi(a.a.a,'build-source-package','');break;case 7:NAi(a.a.a,'check-package','');break;case 8:NAi(a.a.a,'clean-all','');break;case 9:HAi(a.a.a);break;case 10:NAi(a.a.a,Fno,'');break;case 11:IAi(a.a.a);break;case 12:JAi(a.a.a);break;case 13:KAi(a.a.a);break;case 14:eHh(a.a.a.i,new YAi);break;case 15:NAi(a.a.a,'test-package','');break;case 18:a.a.a.H.NF();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nvar YFo='Building package documentation',ZFo='roxygenize-package';$$c(2203,1,Fhn,wRf);_.us=function xRf(a){dQf(this.a,a)};var vib=qHd(2203);$$c(6859,384,{},YAi);_.nm=function ZAi(a){(LWd(a),a)||u$c().OA(3,'Error Terminating Build','Unable to terminate build. Please try again.').PA()};var rTb=qHd(6859);$$c(6860,1,Khn,$Ai);_.zm=function _Ai(){jMe(this.a.p.e.c.c)};var sTb=qHd(6860);$$c(6861,53,{},aBi);_.Bt=function bBi(a){this.a.c=a;LBi(this.b,this.a.c)};var tTb=qHd(6861);$$c(6852,1,Khn,HBi);_.zm=function IBi(){DAi(this.a)};var JTb=qHd(6852);$$c(6853,1,Khn,JBi);_.zm=function KBi(){};var KTb=qHd(6853);$$c(6851,1,Fhn,MBi);_.us=function NBi(a){LBi(this,a)};var LTb=qHd(6851);$$c(6854,1,Khn,OBi);_.zm=function PBi(){NAi(this.a,ZFo,'')};var MTb=qHd(6854);$$c(253,1,RHn);_.xm=function NCi(){KCi((new OCi(this)).a)};$$c(6400,1,Khn,OCi);_.zm=function PCi(){KCi(this.a)};var gUb=qHd(6400);H8m(Gl)(15);\n//# sourceURL=rstudio-15.js\n")
