$wnd.rstudio.runAsyncCallback15("function xAi(){}\nfunction vAi(a){this.a=a}\nfunction AAi(a){this.a=a}\nfunction CAi(a){this.a=a}\nfunction CBi(a){this.a=a}\nfunction Ozi(a){this.a=a}\nfunction gRf(a){this.a=a}\nfunction rzi(a){Dzi(a,new AAi(a))}\nfunction wzi(a){EPf(a.b,new CAi(a))}\nfunction vzi(a){Kik(a.k,new vAi(a),new xAi,iEn)}\nfunction yzi(a){Kik(a.k,new pAi(a,null),new rAi,BLn)}\nfunction zzi(a,b){Sof(a.d,new ZRi(b,true),false)}\nfunction PPf(a,b){(yWd(b),b)&&Bzi(a.a,NEo,'')}\nfunction Qzi(a,b){this.a=a;this.b=b;rkf.call(this)}\nfunction zAi(a,b){zzi(a.a,'devtools::load_all(\"'+b+'\")')}\nfunction BAh(a,b){TEh(a,XNn,'devtools_load_all_path',new vE,b)}\nfunction Dzi(a,b){a.c!=null?zAi(b,a.c):BAh(a.i,new Qzi(a,b))}\nfunction xzi(a){a.G.CF();Fm((ym(),xm),new Ozi(a))}\nfunction Mzi(){qHf.call(this,'Terminating Build...')}\nfunction EPf(a,b){qPf(a,MEo,MEo,HRf(a.g.b.package_dependencies,'roxygen'),dPf(a,'roxygen'),false,new gRf(b))}\nfunction ozi(a,b){var c,d;sJf(a.p.e,null);d=b.outputs;for(c=0;c<d.length;c++)Lyi(a.p,d[c]);b.errors.length>0&&Kyi(a.p,b.errors_base_dir,b.errors,false,0,true,b.type);b.running?z5d(a.a.Cj,true,false):rJf(a.p.e);YLe(a.p.e.c.c)}\nfunction yBi(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=bCi(a.a.b.a);Aoi(a.a,a.a.a)}switch(a.c){case 1:ozi(a.a.a,a.b[0]);break;case 2:a.a.a.G.AF();break;case 3:a.a.a.G.BF();break;case 4:Bzi(a.a.a,smo,'');break;case 5:Bzi(a.a.a,'build-binary-package','');break;case 6:Bzi(a.a.a,'build-source-package','');break;case 7:Bzi(a.a.a,'check-package','');break;case 8:Bzi(a.a.a,'clean-all','');break;case 9:vzi(a.a.a);break;case 10:Bzi(a.a.a,tmo,'');break;case 11:wzi(a.a.a);break;case 12:xzi(a.a.a);break;case 13:yzi(a.a.a);break;case 14:UFh(a.a.a.i,new Mzi);break;case 15:Bzi(a.a.a,'test-package','');break;case 18:a.a.a.G.DF();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nvar MEo='Building package documentation',NEo='roxygenize-package';N$c(2198,1,sgn,gRf);_.us=function hRf(a){PPf(this.a,a)};var vib=dHd(2198);N$c(6847,384,{},Mzi);_.nm=function Nzi(a){(yWd(a),a)||h$c().GA(3,'Error Terminating Build','Unable to terminate build. Please try again.').HA()};var fTb=dHd(6847);N$c(6848,1,xgn,Ozi);_.zm=function Pzi(){YLe(this.a.p.e.c.c)};var gTb=dHd(6848);N$c(6849,53,{},Qzi);_.Bt=function Rzi(a){this.a.c=a;zAi(this.b,this.a.c)};var hTb=dHd(6849);N$c(6840,1,xgn,vAi);_.zm=function wAi(){rzi(this.a)};var xTb=dHd(6840);N$c(6841,1,xgn,xAi);_.zm=function yAi(){};var yTb=dHd(6841);N$c(6839,1,sgn,AAi);_.us=function BAi(a){zAi(this,a)};var zTb=dHd(6839);N$c(6842,1,xgn,CAi);_.zm=function DAi(){Bzi(this.a,NEo,'')};var ATb=dHd(6842);N$c(253,1,FGn);_.xm=function BBi(){yBi((new CBi(this)).a)};N$c(6388,1,xgn,CBi);_.zm=function DBi(){yBi(this.a)};var WTb=dHd(6388);u7m(Gl)(15);\n//# sourceURL=rstudio-15.js\n")
