$wnd.rstudio.runAsyncCallback14("function B2m(a){this.a=a}\nfunction vmn(){IDf.call(this)}\nfunction T_h(a,b){d_h(a,Tdo,'svn_cleanup',new nH,b)}\nfunction x2m(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=Kln(a.a.b.a);NKi(a.a,a.a.a)}switch(a.c){case 1:a.a.a.c.G.PH();break;case 2:a.a.a.c.G.QH();break;case 3:a.a.a.c.G.RH();break;case 4:N1m(a.a.a,a.b[0]);break;case 5:O1m(a.a.a,a.b[0]);break;case 6:a.a.a.c.yO();break;case 7:a.a.a.c.zO();break;case 8:a.a.a.c.AO();break;case 9:a.a.a.c.BO();break;case 10:a.a.a.c.CO();break;case 11:a.a.a.c.DO();break;case 12:P1m(a.a.a,a.b[0]);break;case 13:a.a.a.c.EO();break;case 14:Q1m(a.a.a,a.b[0]);break;case 15:a.a.a.c.G.SH();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nS2c(275,1,n6n);_.xm=function A2m(){x2m((new B2m(this)).a)};S2c(6419,1,UEn,B2m);_.zm=function C2m(){x2m(this.a)};var tWc=AMd(6419);S2c(7535,1597,H0n);_.yO=function _fn(){};_.zO=function agn(){Yfn(this,false,null,L2m(this.i.k))};_.AO=function bgn(){Dgn(this.b,L2m(this.i.k))};_.BO=function cgn(){VYh(this.b.c,new Hgn)};_.CO=function dgn(){WYh(this.b.c,new Jgn)};_.DO=function egn(){XYh(this.b.c,new Lgn)};_.EO=function fgn(){Yfn(this,true,null,new Lld)};S2c(6310,54,{},vmn);_.Au=function wmn(a){kpe(new p4m(a),true)};var i_c=AMd(6310);S2c(7543,1597,H0n);_.yO=function unn(){T_h(this.c,new n5m('SVN Cleanup','Cleaning up working directory...',750))};_.zO=function vnn(){kpe(Fpn(this.a.d.a),true)};_.AO=function wnn(){cmn(this.a)};_.BO=function xnn(){c0h(this.a.f,new tmn)};_.CO=function ynn(){c0h(this.a.f,new vmn)};_.DO=function znn(){};_.EO=function Ann(){rnn(this,null,new Lld)};Jvn(Il)(14);\n//# sourceURL=rstudio-14.js\n")
