$wnd.rstudio.runAsyncCallback3("function Fpi(a){var b;o7m[b=++p7m]=Fpi;this.a=(q7m[b]=P7m,a);p7m=b-1}\nfunction Qpi(a){var b;o7m[b=++p7m]=Qpi;this.a=(q7m[b]=z7m,a);p7m=b-1}\nfunction Hpi(a){var b;o7m[b=++p7m]=Hpi;this.a=(q7m[b]=Ian,a);p7m=b-1}\nfunction Are(a,b){var c,d;o7m[d=++p7m]=Are;for(q7m[d]=lcn,c=0;(q7m[d]=lcn,c)<(q7m[d]=Sfn,a.p.a).length;q7m[d]=lcn,c++){if(Igd((q7m[d]=Nfn,a).p,c).JM==b){Zse((q7m[d]=w9m,(q7m[d]=C9m,a).s),XHd((r7m=(q7m[d]=C9m,c),q7m[d]=w9m,r7m)));break}}p7m=d-1}\nfunction Epi(a,b){var c;o7m[c=++p7m]=Epi;this.c=(q7m[c]=O8m,a);this.b=(r7m=Z8h((q7m[c]=ncn,a).c,rEo,sEo,(r7m=gSn,q7m[c]=gun,r7m)),q7m[c]=ncn,r7m).mF();this.a=(r7m=Z8h((q7m[c]=h8m,a).c,tEo,uEo,(r7m=vEo,q7m[c]=jun,r7m)),q7m[c]=h8m,r7m).mF();$h((q7m[c]=P7m,b),new Fpi(this),(r7m=(q7m[c]=U7m,DA)?DA:(DA=new Yx),q7m[c]=Kqn,r7m));p7m=c-1}\nfunction Cpi(a){var b,c;o7m[c=++p7m]=Cpi;b=Dpi((q7m[c]=Q7m,a),'weaving Rnw files',(q7m[c]=Idn,a).b,(r7m=Z8h((q7m[c]=U9m,a).c.c,rEo,sEo,(r7m=gSn,q7m[c]=gun,r7m)),q7m[c]=Q7m,r7m));(q7m[c]=s8m,b)||Dpi((q7m[c]=Gdn,a),'LaTeX typesetting',(q7m[c]=u8m,a).a,(r7m=Z8h((q7m[c]=Ccn,a).c.c,tEo,uEo,(r7m=vEo,q7m[c]=jun,r7m)),q7m[c]=Gdn,r7m));p7m=c-1}\nfunction Api(a,b,c){var d,e;o7m[e=++p7m]=Api;q7m[e]=Pcn,d=jki((q7m[e]=Ukn,(q7m[e]=Pcn,a).b.a));Fre((q7m[e]=r8m,d),(r7m=xbi(uvg((q7m[e]=oan,(q7m[e]=n9m,rff(),(q7m[e]=r8m,qff)).a))),q7m[e]=r8m,r7m));!(q7m[e]=Xbn,!(q7m[e]=w8m,b))&&Are((q7m[e]=T7m,d),b);Lre((q7m[e]=R7m,d),c);Bje((q7m[e]=S7m,d),(r7m=true,q7m[e]=Hfn,r7m));new Epi((q7m[e]=y8m,a),d);((q7m[e]=I7m,Tlf())||!!(q7m[e]=qcn,$wnd).remoteDesktop)&&(q7m[e]=C7m,Xlf());p7m=e-1}\nfunction Mpi(b){var c,d;o7m[c=++p7m]=Mpi;try{if((q7m[c]=M7m,b).c<0){d=true;return}(q7m[c]=Fbn,!(q7m[c]=q8m,b).a.a)&&(q7m[c]=N7m,(q7m[c]=N7m,b).a.a=Gwi((q7m[c]=Tkn,b.a.b.a)));switch((q7m[c]=O7m,b).c){case 1:Api((q7m[c]=ian,b).a.a,null,(r7m=true,q7m[c]=gan,r7m));break;case 2:Api((q7m[c]=w8m,b).a.a,b.b[0],EGd(b.b[1]));}}catch(a){a=d$c(a);p7m=(q7m[c]=K8m,c);throw e$c(a)}finally{(q7m[c]=U7m,b).c<=0&&b.b[0]!=null&&b.b[0].zm();d&&(p7m=c-1)}p7m=c-1}\nfunction Dpi(a,b,c,d){var e;o7m[e=++p7m]=Dpi;if($G((q7m[e]=sfn,c))!==$G(d.mF())&&$G((q7m[e]=xdn,d).bq())!==$G(d.mF())){n_d(2,'Project Option Unchanged','You changed the global option for '+(q7m[e]=Gan,b)+XPn+(q7m[e]=Han,d).mF()+', however the current project is '+'still configured to use '+(q7m[e]=tcn,d).bq()+'.\\n\\n'+'Do you want to edit the options for the current '+'project as well?',new Hpi((q7m[e]=Ian,a)),(r7m=true,q7m[e]=jan,r7m));p7m=e-1;return true}else{p7m=e-1;return false}p7m=e-1}\nG$c(2817,1,{},Epi);var mQb=YGd(2817);G$c(2818,1,lNn,Fpi);_.cn=function Gpi(a){var b;o7m[b=++p7m]=Gpi;Cpi((q7m[b]=P7m,this.a));p7m=b-1};var kQb=YGd(2818);G$c(2819,1,UQn,Hpi);_.zm=function Ipi(){var a;o7m[a=++p7m]=Ipi;$4d((r7m=(q7m[a]='6341',(q7m[a]=Ian,this.a).c.a.Ug),q7m[a]=Ian,r7m));p7m=a-1};var lQb=YGd(2819);G$c(626,1,Lio);_.xm=function Ppi(){var a;o7m[a=++p7m]=Ppi;Mpi((q7m[a]=K7m,(new Qpi((r7m=this,q7m[a]=z7m,r7m))).a));p7m=a-1};G$c(2873,1,uQn,Qpi);_.zm=function Rpi(){var a;o7m[a=++p7m]=Rpi;Mpi((q7m[a]=K7m,this.a));p7m=a-1};var nQb=YGd(2873);n7m(Il)(3);\n//# sourceURL=rstudio-3.js\n")
