$wnd.rstudio.runAsyncCallback3("function Rqi(a){var b;B8m[b=++C8m]=Rqi;this.a=(D8m[b]=a9m,a);C8m=b-1}\nfunction Tqi(a){var b;B8m[b=++C8m]=Tqi;this.a=(D8m[b]=Vbn,a);C8m=b-1}\nfunction ari(a){var b;B8m[b=++C8m]=ari;this.a=(D8m[b]=N8m,a);C8m=b-1}\nfunction Nre(a,b){var c,d;B8m[d=++C8m]=Nre;for(D8m[d]=ydn,c=0;(D8m[d]=ydn,c)<(D8m[d]=dhn,a.p.a).length;D8m[d]=ydn,c++){if(Vgd((D8m[d]=$gn,a).p,c).TM==b){kte((D8m[d]=Kan,(D8m[d]=Qan,a).s),iId((E8m=(D8m[d]=Qan,c),D8m[d]=Kan,E8m)));break}}C8m=d-1}\nfunction Qqi(a,b){var c;B8m[c=++C8m]=Qqi;this.c=(D8m[c]=_9m,a);this.b=(E8m=jai((D8m[c]=Adn,a).c,FFo,GFo,(E8m=uTn,D8m[c]=uvn,E8m)),D8m[c]=Adn,E8m).wF();this.a=(E8m=jai((D8m[c]=u9m,a).c,HFo,IFo,(E8m=JFo,D8m[c]=xvn,E8m)),D8m[c]=u9m,E8m).wF();$h((D8m[c]=a9m,b),new Rqi(this),(E8m=(D8m[c]=f9m,DA)?DA:(DA=new Yx),D8m[c]=Xrn,E8m));C8m=c-1}\nfunction Oqi(a){var b,c;B8m[c=++C8m]=Oqi;b=Pqi((D8m[c]=b9m,a),'weaving Rnw files',(D8m[c]=Ven,a).b,(E8m=jai((D8m[c]=gbn,a).c.c,FFo,GFo,(E8m=uTn,D8m[c]=uvn,E8m)),D8m[c]=b9m,E8m));(D8m[c]=F9m,b)||Pqi((D8m[c]=Ten,a),'LaTeX typesetting',(D8m[c]=H9m,a).a,(E8m=jai((D8m[c]=Pdn,a).c.c,HFo,IFo,(E8m=JFo,D8m[c]=xvn,E8m)),D8m[c]=Ten,E8m));C8m=c-1}\nfunction Mqi(a,b,c){var d,e;B8m[e=++C8m]=Mqi;D8m[e]=aen,d=vli((D8m[e]=fmn,(D8m[e]=aen,a).b.a));Sre((D8m[e]=E9m,d),(E8m=Jci(Gwg((D8m[e]=Cbn,(D8m[e]=Ban,Eff(),(D8m[e]=E9m,Dff)).a))),D8m[e]=E9m,E8m));!(D8m[e]=idn,!(D8m[e]=J9m,b))&&Nre((D8m[e]=e9m,d),b);Yre((D8m[e]=c9m,d),c);Oje((D8m[e]=d9m,d),(E8m=true,D8m[e]=Ugn,E8m));new Qqi((D8m[e]=L9m,a),d);((D8m[e]=V8m,emf())||!!(D8m[e]=Ddn,$wnd).remoteDesktop)&&(D8m[e]=Q8m,imf());C8m=e-1}\nfunction Yqi(b){var c,d;B8m[c=++C8m]=Yqi;try{if((D8m[c]=Z8m,b).c<0){d=true;return}(D8m[c]=Scn,!(D8m[c]=D9m,b).a.a)&&(D8m[c]=$8m,(D8m[c]=$8m,b).a.a=Sxi((D8m[c]=emn,b.a.b.a)));switch((D8m[c]=_8m,b).c){case 1:Mqi((D8m[c]=wbn,b).a.a,null,(E8m=true,D8m[c]=ubn,E8m));break;case 2:Mqi((D8m[c]=J9m,b).a.a,b.b[0],RGd(b.b[1]));}}catch(a){a=q$c(a);C8m=(D8m[c]=X9m,c);throw r$c(a)}finally{(D8m[c]=f9m,b).c<=0&&b.b[0]!=null&&b.b[0].zm();d&&(C8m=c-1)}C8m=c-1}\nfunction Pqi(a,b,c,d){var e;B8m[e=++C8m]=Pqi;if($G((D8m[e]=Fgn,c))!==$G(d.wF())&&$G((D8m[e]=Ken,d).bq())!==$G(d.wF())){A_d(2,'Project Option Unchanged','You changed the global option for '+(D8m[e]=Tbn,b)+jRn+(D8m[e]=Ubn,d).wF()+', however the current project is '+'still configured to use '+(D8m[e]=Gdn,d).bq()+'.\\n\\n'+'Do you want to edit the options for the current '+'project as well?',new Tqi((D8m[e]=Vbn,a)),(E8m=true,D8m[e]=xbn,E8m));C8m=e-1;return true}else{C8m=e-1;return false}C8m=e-1}\nT$c(2823,1,{},Qqi);var yQb=jHd(2823);T$c(2824,1,zOn,Rqi);_.cn=function Sqi(a){var b;B8m[b=++C8m]=Sqi;Oqi((D8m[b]=a9m,this.a));C8m=b-1};var wQb=jHd(2824);T$c(2825,1,gSn,Tqi);_.zm=function Uqi(){var a;B8m[a=++C8m]=Uqi;l5d((E8m=(D8m[a]='6341',(D8m[a]=Vbn,this.a).c.a.Ug),D8m[a]=Vbn,E8m));C8m=a-1};var xQb=jHd(2825);T$c(627,1,Yjo);_.xm=function _qi(){var a;B8m[a=++C8m]=_qi;Yqi((D8m[a]=X8m,(new ari((E8m=this,D8m[a]=N8m,E8m))).a));C8m=a-1};T$c(2879,1,IRn,ari);_.zm=function bri(){var a;B8m[a=++C8m]=bri;Yqi((D8m[a]=X8m,this.a));C8m=a-1};var zQb=jHd(2879);A8m(Il)(3);\n//# sourceURL=rstudio-3.js\n")
