$wnd.rstudio.runAsyncCallback22("function dYj(a){this.a=a}\nfunction wXj(a,b){this.a=a;this.b=b}\nfunction iXj(a,b){a.k?J_d(4,'Stop R Markdown Rendering',\"The rendering of '\"+a.g+\"' is in progress. Do you \"+'want to terminate and close the tab?',false,new wXj(a,b),null,null,WEn,cin,true):b.zm()}\nfunction _Xj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=fYj(a.a.b.a);Mpi(a.a,a.a.a)}switch(a.c){case 1:Ozi(a.a.a,a.b[0]);break;case 2:iXj(a.a.a,a.b[0]);break;case 3:jXj(a.a.a);break;case 4:a.a.a.H.KF();break;case 5:a.a.a.H.LF();break;case 6:kXj(a.a.a,a.b[0]);break;case 7:lXj(a.a.a,a.b[0]);break;case 8:mXj(a.a.a,a.b[0]);break;case 9:nXj(a.a.a,a.b[0]);break;case 10:a.a.a.H.MF();break;case 11:a.a.a.H.NF();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\n$$c(6945,1,iin,wXj);_.zm=function xXj(){oXj(this.a);this.b.zm()};var ndc=qHd(6945);$$c(315,1,RHn);_.xm=function cYj(){_Xj((new dYj(this)).a)};$$c(6443,1,Khn,dYj);_.zm=function eYj(){_Xj(this.a)};var wdc=qHd(6443);H8m(Gl)(22);\n//# sourceURL=rstudio-22.js\n")
