$wnd.rstudio.runAsyncCallback16("function Dek(a){this.a=a}\nfunction adk(a,b){this.a=a;this.b=b;nie.call(this)}\nfunction Fck(a,b){a.a=b;Sdk(a.n,Bck(a,null),a.a.file_path)}\nfunction Hck(a,b){b.slide_index==0&&Sti(a.n);a.a=b;Sdk(a.n,Bck(a,null),a.a.file_path)}\nfunction Nck(a){E4e('Opening Presentation...',wwd());Sof(a.c,new Nqf,false)}\nfunction Cck(a){var b;b=PHf(new QHf(0,'Closing Presentation...'));Zzh(a.j,new adk(a,b))}\nfunction Zzh(a,b){TEh(a,XNn,'close_presentation_pane',new vE,b)}\nfunction Mck(a){var b;a.G.CF();!!a.a&&a.a.active&&(b=nfe(nh(a.n.d).contentWindow),!(!PId(ghn,b)&&!PId('javascript:void(0)',b)))&&Fck(a,a.a)}\nfunction zek(a){var b,c;try{if(a.c<0)return;if(!a.a.a){a.a.a=nfk(a.a.b.a);Aoi(a.a,a.a.a)}switch(a.c){case 1:Cck((c=a.a.a,a.b[0],c));break;case 2:Hck(a.a.a,a.b[0]);break;case 3:a.a.a.G.AF();break;case 4:a.a.a.G.BF();break;case 5:Mck(a.a.a);break;case 6:Nck((b=a.a.a,a.b[0],b));break;case 7:a.a.a.G.DF();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nN$c(6862,31,{},adk);_.Bt=function cdk(a){var b;Sof((b=this,a,b).a.c,new Nqf,false)};_.At=function bdk(a){fHf(this.b,a.a?a.a.c:a.d)};var aic=dHd(6862);N$c(454,1,FGn);_.xm=function Cek(){zek((new Dek(this)).a)};N$c(6404,1,xgn,Dek);_.zm=function Eek(){zek(this.a)};var zic=dHd(6404);u7m(Gl)(16);\n//# sourceURL=rstudio-16.js\n")
