$wnd.rstudio.runAsyncCallback26("function oWj(){}\nfunction RWj(a){var b;Qwn[b=++Rwn]=RWj;this.a=(Swn[b]=nDn,a);Rwn=b-1}\nfunction hWj(a,b){var c;Qwn[c=++Rwn]=hWj;dZj((Swn[c]=lzn,a).c,b);Rwn=c-1}\nfunction aWj(a,b){var c,d,e;Qwn[e=++Rwn]=aWj;c=ZZj((Twn=y0j((Swn[e]=nDn,(Swn[e]=jCn,a).d.a)),Swn[e]=jCn,Twn));if((Swn[e]=HAn,(Swn[e]=Xwn,c).a).length==0){m4j((Swn[e]=qAn,a).b,false);(Swn[e]=_Bn,b).zm()}d=l_d(m_d(new r_d(null,(Twn=new kYd((Twn=(Swn[e]=aBn,c),Swn[e]=Yxn,Twn)),Swn[e]=yyn,Twn)),(Twn=(Swn[e]=LBn,new oWj),Swn[e]=aBn,Twn)));if(y2c((Swn[e]=bzn,d),(Twn=0,Swn[e]=Wxn,Twn))>0){(Twn=(Swn[e]=bxn,m2c()).hC(1,'Local Jobs Still Running',(Twn='The Jobs tab cannot be closed while there '+(y2c((Swn[e]=czn,d),(Twn=1,Swn[e]=Wxn,Twn))>0?'are unfinished local jobs':'is an unfinished local job')+'.'+'\\n\\nWait until all local jobs have completed.',Swn[e]=bxn,Twn)),Swn[e]=UBn,Twn).iC();Rwn=e-1;return}m4j((Swn[e]=LAn,a).b,false);(Swn[e]=MAn,b).zm();Rwn=e-1}\nfunction NWj(b){var c,d;Qwn[c=++Rwn]=NWj;try{if((Swn[c]=gyn,b).c<0){d=true;return}if(Swn[c]=oBn,!(Swn[c]=aCn,b).a.a){Swn[c]=_En,(Swn[c]=_En,b).a.a=I0j((Swn[c]=fCn,b.a.b.a));SLi((Swn[c]=GAn,b).a,b.a.a)}switch((Swn[c]=fJn,b).c){case 1:aWj((Swn[c]=XEn,b).a.a,b.b[0]);break;case 2:bWj((Swn[c]=Vzn,b).a.a);break;case 3:(Swn[c]=pxn,(Swn[c]=pAn,b).a.a.H).WH();break;case 4:(Swn[c]=$An,(Swn[c]=aFn,b).a.a.H).XH();break;case 5:cWj((Swn[c]=aBn,b).a.a,b.b[0]);break;case 6:dWj((Swn[c]=DAn,b).a.a,b.b[0]);break;case 7:eWj((Swn[c]=_yn,b).a.a,b.b[0]);break;case 8:fWj((Swn[c]=czn,b).a.a,b.b[0]);break;case 9:gWj((Swn[c]=lCn,b).a.a,b.b[0]);break;case 10:(Swn[c]=byn,(Swn[c]=Pxn,b).a.a.H).YH();break;case 11:(Swn[c]=_xn,(Swn[c]=UBn,b).a.a.H).ZH();break;case 12:hWj((Swn[c]=Qxn,b).a.a,b.b[0]);}}catch(a){a=v2c(a);Rwn=(Swn[c]=iCn,c);throw w2c(a)}finally{(Swn[c]=Sxn,b).c<=0&&b.b[0]!=null&&b.b[0].zm();d&&(Rwn=c-1)}Rwn=c-1}\nY2c(6998,1,{},oWj);_.kt=function pWj(a){var b,c;Qwn[b=++Rwn]=pWj;c=(Swn[b]=LBn,a).type==1&&(Swn[b]=kCn,a.state)==2;Rwn=b-1;return c};var Sac=GMd(6998);Y2c(317,1,HLo);_.xm=function QWj(){var a;Qwn[a=++Rwn]=QWj;NWj((Swn[a]=eyn,(new RWj((Twn=this,Swn[a]=nDn,Twn))).a));Rwn=a-1};Y2c(6504,1,feo,RWj);_.zm=function SWj(){var a;Qwn[a=++Rwn]=SWj;NWj((Swn[a]=eyn,this.a));Rwn=a-1};var Zac=GMd(6504);Pwn(Kl)(26);\n//# sourceURL=rstudio-26.js\n")
