$wnd.rstudio.runAsyncCallback16("function UDk(a){var b;Qwn[b=++Rwn]=UDk;this.a=(Swn[b]=axn,a);Rwn=b-1}\nfunction rCk(a,b){var c;Qwn[c=++Rwn]=rCk;this.a=(Swn[c]=sKn,a);this.b=b;Xne.call(this);Rwn=c-1}\nfunction TBk(a){var b,c;Qwn[c=++Rwn]=TBk;b=o_f(new p_f(0,(Twn='Closing Presentation...',Swn[c]=CNn,Twn)));oXh((Swn[c]=sKn,a).k,new rCk(a,b));Rwn=c-1}\nfunction oXh(a,b){var c;Qwn[c=++Rwn]=oXh;i0h((Swn[c]=kLp,a),EYo,'close_presentation_pane',(Swn[c]=bap,new iH),(Twn=(Swn[c]=kLp,b),Swn[c]=cap,Twn));Rwn=c-1}\nfunction WBk(a,b){var c;Qwn[c=++Rwn]=WBk;(Swn[c]=BKn,a).a=b;hDk((Swn[c]=CDn,a).o,SBk(a,(Twn=null,Swn[c]=gNn,Twn)),(Twn=(Swn[c]=Uwn,(Swn[c]=CDn,a).a.file_path),Swn[c]=CDn,Twn));Rwn=c-1}\nfunction cCk(a){var b;Qwn[b=++Rwn]=cCk;_nf('Opening Presentation...',(Swn[b]=lFn,qBd()));qIf((Swn[b]=b9n,(Swn[b]=ryn,a).c),new lKf,(Twn=false,Swn[b]=Bxn,Twn));Rwn=b-1}\nfunction YBk(a,b){var c;Qwn[c=++Rwn]=YBk;(Swn[c]=gxn,(Swn[c]=HAn,b).slide_index)==0&&hRi((Swn[c]=oyn,a).o);Swn[c]=BKn,(Swn[c]=Dyn,a).a=b;hDk((Swn[c]=CDn,(Swn[c]=Dyn,a).o),SBk((Swn[c]=Dyn,a),(Twn=null,Swn[c]=gNn,Twn)),(Twn=(Swn[c]=Uwn,(Swn[c]=CDn,(Swn[c]=Dyn,a).a).file_path),Swn[c]=CDn,Twn));Rwn=c-1}\nfunction bCk(a){var b,c;Qwn[c=++Rwn]=bCk;(Swn[c]=byn,(Swn[c]=yCn,a).H).YH();!(Swn[c]=FBn,!(Swn[c]=$Jn,a).a)&&(Swn[c]=hxn,(Swn[c]=Vwn,a).a.active)&&(b=Xke((Twn=(Swn[c]=rIn,ph((Twn=(Swn[c]=EBn,(Swn[c]=aDn,a).o.d),Swn[c]=$xn,Twn)).contentWindow),Swn[c]=EBn,Twn)),(Swn[c]=aDn,!(!qOd(Seo,(Swn[c]=qCn,b))&&!qOd('javascript:void(0)',(Swn[c]=lFn,b)))))&&WBk((Swn[c]=xyn,a),a.a);Rwn=c-1}\nfunction QDk(b){var c,d,e,f;Qwn[e=++Rwn]=QDk;try{if((Swn[e]=dxn,b).c<0){f=true;return}if(Swn[e]=oBn,!(Swn[e]=kyn,b).a.a){Swn[e]=txn,(Swn[e]=txn,b).a.a=EEk((Swn[e]=_yn,b.a.b.a));SLi((Swn[e]=yyn,b).a,b.a.a)}switch((Swn[e]=lzn,b).c){case 1:TBk((d=(Swn[e]=vxn,b).a.a,b.b[0],d));break;case 2:YBk((Swn[e]=Wxn,b).a.a,b.b[0]);break;case 3:(Swn[e]=pxn,(Swn[e]=Dxn,b).a.a.H).WH();break;case 4:(Swn[e]=$An,(Swn[e]=Ezn,b).a.a.H).XH();break;case 5:bCk((Swn[e]=Fzn,b).a.a);break;case 6:cCk((c=(Swn[e]=iCn,b).a.a,b.b[0],c));break;case 7:(Swn[e]=_xn,(Swn[e]=_En,b).a.a.H).ZH();}}catch(a){a=v2c(a);Rwn=(Swn[e]=uyn,e);throw w2c(a)}finally{(Swn[e]=NAn,b).c<=0&&b.b[0]!=null&&b.b[0].zm();f&&(Rwn=e-1)}Rwn=e-1}\nY2c(6914,31,{},rCk);_.xu=function tCk(a){var b,c;Qwn[c=++Rwn]=tCk;qIf((Swn[c]=b9n,(Swn[c]=tDn,(Swn[c]=xMn,b=this,a,b).a).c),new lKf,(Twn=false,Swn[c]=Bxn,Twn));Rwn=c-1};_.wu=function sCk(a){var b;Qwn[b=++Rwn]=sCk;G$f((Swn[b]=rMn,this.b),(Twn=(Swn[b]=zyn,a.a)?(Swn[b]=ixn,(Swn[b]=vxn,(Swn[b]=rMn,a).a).c):(Swn[b]=Vxn,(Swn[b]=rMn,a).d),Swn[b]=rMn,Twn));Rwn=b-1};var Vlc=GMd(6914);Y2c(452,1,HLo);_.xm=function TDk(){var a;Qwn[a=++Rwn]=TDk;QDk((Swn[a]=Gxn,(new UDk((Twn=this,Swn[a]=axn,Twn))).a));Rwn=a-1};Y2c(6456,1,feo,UDk);_.zm=function VDk(){var a;Qwn[a=++Rwn]=VDk;QDk((Swn[a]=Gxn,this.a));Rwn=a-1};var smc=GMd(6456);Pwn(Kl)(16);\n//# sourceURL=rstudio-16.js\n")
