$wnd.rstudio.runAsyncCallback15("function VXi(){}\nfunction kXi(a){this.a=a}\nfunction TXi(a){this.a=a}\nfunction YXi(a){this.a=a}\nfunction $Xi(a){this.a=a}\nfunction $Yi(a){this.a=a}\nfunction P8f(a){this.a=a}\nfunction PWi(a){_Wi(a,new YXi(a))}\nfunction UWi(a){l7f(a.b,new $Xi(a))}\nfunction TWi(a){gIk(a.k,new TXi(a),new VXi,f5n)}\nfunction WWi(a){gIk(a.k,new NXi(a,null),new PXi,vco)}\nfunction XWi(a,b){xIf(a.d,new vdj(b,true),false)}\nfunction w7f(a,b){(g0d(b),b)&&ZWi(a.a,d7o,'')}\nfunction mXi(a,b){this.a=a;this.b=b;VDf.call(this)}\nfunction XXi(a,b){XWi(a.a,'devtools::load_all(\"'+b+'\")')}\nfunction ZXh(a,b){p0h(a,efo,'devtools_load_all_path',new nH,b)}\nfunction _Wi(a,b){a.c!=null?XXi(b,a.c):ZXh(a.i,new mXi(a,b))}\nfunction VWi(a){a.H.aI();Hm((Am(),zm),new kXi(a))}\nfunction iXi(){Y$f.call(this,'Terminating Build...')}\nfunction l7f(a,b){Z6f(a,c7o,c7o,o9f(a.g.b.package_dependencies,'roxygen'),M6f(a,'roxygen'),false,new P8f(b))}\nfunction MWi(a,b){var c,d;$0f(a.p.e,null);d=b.outputs;for(c=0;c<d.length;c++)hWi(a.p,d[c]);b.errors.length>0&&gWi(a.p,b.errors_base_dir,b.errors,false,0,true,b.type);b.running?obe(a.a.Cj,true,false):Z0f(a.p.e);k3e(a.p.e.c.c)}\nfunction WYi(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=zZi(a.a.b.a);ZLi(a.a,a.a.a)}switch(a.c){case 1:MWi(a.a.a,a.b[0]);break;case 2:a.a.a.H.ZH();break;case 3:a.a.a.H._H();break;case 4:ZWi(a.a.a,dQo,'');break;case 5:ZWi(a.a.a,'build-binary-package','');break;case 6:ZWi(a.a.a,'build-source-package','');break;case 7:ZWi(a.a.a,'check-package','');break;case 8:ZWi(a.a.a,'clean-all','');break;case 9:TWi(a.a.a);break;case 10:ZWi(a.a.a,eQo,'');break;case 11:UWi(a.a.a);break;case 12:VWi(a.a.a);break;case 13:WWi(a.a.a);break;case 14:q1h(a.a.a.i,new iXi);break;case 15:ZWi(a.a.a,'test-package','');break;case 18:a.a.a.H.bI();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nvar c7o='Building package documentation',d7o='roxygenize-package';d3c(2222,1,_Fn,P8f);_.vt=function Q8f(a){w7f(this.a,a)};var Tlb=NMd(2222);d3c(6900,383,{},iXi);_.nm=function jXi(a){(g0d(a),a)||t2c().kC(3,'Error Terminating Build','Unable to terminate build. Please try again.').lC()};var VWb=NMd(6900);d3c(6901,1,eGn,kXi);_.zm=function lXi(){k3e(this.a.p.e.c.c)};var WWb=NMd(6901);d3c(6902,54,{},mXi);_.Au=function nXi(a){this.a.c=a;XXi(this.b,this.a.c)};var XWb=NMd(6902);d3c(6893,1,eGn,TXi);_.zm=function UXi(){PWi(this.a)};var lXb=NMd(6893);d3c(6894,1,eGn,VXi);_.zm=function WXi(){};var mXb=NMd(6894);d3c(6892,1,_Fn,YXi);_.vt=function ZXi(a){XXi(this,a)};var nXb=NMd(6892);d3c(6895,1,eGn,$Xi);_.zm=function _Xi(){ZWi(this.a,d7o,'')};var oXb=NMd(6895);d3c(252,1,y7n);_.xm=function ZYi(){WYi((new $Yi(this)).a)};d3c(6441,1,eGn,$Yi);_.zm=function _Yi(){WYi(this.a)};var KXb=NMd(6441);Wwn(Il)(15);\n//# sourceURL=rstudio-15.js\n")
