$wnd.rstudio.runAsyncCallback26("function iVj(){}\nfunction LVj(a){this.a=a}\nfunction bVj(a,b){ZXj(a.c,b)}\nfunction WUj(a,b){var c,d;c=TYj(s_j(a.d.a));if(c.a.length==0){g3j(a.b,false);b.zm()}d=f_d(g_d(new l_d(null,new eYd(c)),new iVj));if(s2c(d,0)>0){g2c().cC(1,'Local Jobs Still Running','The Jobs tab cannot be closed while there '+(s2c(d,1)>0?'are unfinished local jobs':'is an unfinished local job')+'.'+'\\n\\nWait until all local jobs have completed.').dC();return}g3j(a.b,false);b.zm()}\nfunction HVj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=C_j(a.a.b.a);NKi(a.a,a.a.a)}switch(a.c){case 1:WUj(a.a.a,a.b[0]);break;case 2:XUj(a.a.a);break;case 3:a.a.a.G.PH();break;case 4:a.a.a.G.QH();break;case 5:YUj(a.a.a,a.b[0]);break;case 6:ZUj(a.a.a,a.b[0]);break;case 7:$Uj(a.a.a,a.b[0]);break;case 8:_Uj(a.a.a,a.b[0]);break;case 9:aVj(a.a.a,a.b[0]);break;case 10:a.a.a.G.RH();break;case 11:a.a.a.G.SH();break;case 12:bVj(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nS2c(6987,1,{},iVj);_.nt=function jVj(a){return a.type==1&&a.state==2};var Nac=AMd(6987);S2c(317,1,n6n);_.xm=function KVj(){HVj((new LVj(this)).a)};S2c(6493,1,UEn,LVj);_.zm=function MVj(){HVj(this.a)};var Uac=AMd(6493);Jvn(Il)(26);\n//# sourceURL=rstudio-26.js\n")
