$wnd.rstudio.runAsyncCallback22("function Djk(a){this.a=a}\nfunction Wik(a,b){this.a=a;this.b=b}\nfunction Iik(a,b){a.k?l5d(4,'Stop R Markdown Rendering',\"The rendering of '\"+a.g+\"' is in progress. Do you \"+'want to terminate and close the tab?',false,new Wik(a,b),null,null,H4n,yGn,true):b.zm()}\nfunction zjk(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=Fjk(a.a.b.a);ZLi(a.a,a.a.a)}switch(a.c){case 1:$Vi(a.a.a,a.b[0]);break;case 2:Iik(a.a.a,a.b[0]);break;case 3:Jik(a.a.a);break;case 4:a.a.a.H.ZH();break;case 5:a.a.a.H._H();break;case 6:Kik(a.a.a,a.b[0]);break;case 7:Lik(a.a.a,a.b[0]);break;case 8:Mik(a.a.a,a.b[0]);break;case 9:Nik(a.a.a,a.b[0]);break;case 10:a.a.a.H.aI();break;case 11:a.a.a.H.bI();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nd3c(6986,1,EGn,Wik);_.zm=function Xik(){Oik(this.a);this.b.zm()};var $gc=NMd(6986);d3c(314,1,y7n);_.xm=function Cjk(){zjk((new Djk(this)).a)};d3c(6484,1,eGn,Djk);_.zm=function Ejk(){zjk(this.a)};var hhc=NMd(6484);Wwn(Il)(22);\n//# sourceURL=rstudio-22.js\n")
