$wnd.rstudio.runAsyncCallback26("function vWj(){}\nfunction YWj(a){this.a=a}\nfunction oWj(a,b){kZj(a.c,b)}\nfunction hWj(a,b){var c,d;c=e$j(F0j(a.d.a));if(c.a.length==0){t4j(a.b,false);b.zm()}d=s_d(t_d(new y_d(null,new rYd(c)),new vWj));if(F2c(d,0)>0){t2c().kC(1,'Local Jobs Still Running','The Jobs tab cannot be closed while there '+(F2c(d,1)>0?'are unfinished local jobs':'is an unfinished local job')+'.'+'\\n\\nWait until all local jobs have completed.').lC();return}t4j(a.b,false);b.zm()}\nfunction UWj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=P0j(a.a.b.a);ZLi(a.a,a.a.a)}switch(a.c){case 1:hWj(a.a.a,a.b[0]);break;case 2:iWj(a.a.a);break;case 3:a.a.a.H.ZH();break;case 4:a.a.a.H._H();break;case 5:jWj(a.a.a,a.b[0]);break;case 6:kWj(a.a.a,a.b[0]);break;case 7:lWj(a.a.a,a.b[0]);break;case 8:mWj(a.a.a,a.b[0]);break;case 9:nWj(a.a.a,a.b[0]);break;case 10:a.a.a.H.aI();break;case 11:a.a.a.H.bI();break;case 12:oWj(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nd3c(6999,1,{},vWj);_.nt=function wWj(a){return a.type==1&&a.state==2};var Zac=NMd(6999);d3c(317,1,y7n);_.xm=function XWj(){UWj((new YWj(this)).a)};d3c(6505,1,eGn,YWj);_.zm=function ZWj(){UWj(this.a)};var ebc=NMd(6505);Wwn(Il)(26);\n//# sourceURL=rstudio-26.js\n")
