$wnd.rstudio.runAsyncCallback16("function Qfk(a){this.a=a}\nfunction nek(a,b){this.a=a;this.b=b;Aie.call(this)}\nfunction Sdk(a,b){a.a=b;dfk(a.o,Odk(a,null),a.a.file_path)}\nfunction Udk(a,b){b.slide_index==0&&cvi(a.o);a.a=b;dfk(a.o,Odk(a,null),a.a.file_path)}\nfunction $dk(a){R4e('Opening Presentation...',Jwd());gpf(a.c,new brf,false)}\nfunction Pdk(a){var b;b=dIf(new eIf(0,'Closing Presentation...'));jBh(a.k,new nek(a,b))}\nfunction jBh(a,b){dGh(a,iPn,'close_presentation_pane',new vE,b)}\nfunction Zdk(a){var b;a.H.MF();!!a.a&&a.a.active&&(b=Afe(nh(a.o.d).contentWindow),!(!aJd(vin,b)&&!aJd('javascript:void(0)',b)))&&Sdk(a,a.a)}\nfunction Mfk(a){var b,c;try{if(a.c<0)return;if(!a.a.a){a.a.a=Agk(a.a.b.a);Mpi(a.a,a.a.a)}switch(a.c){case 1:Pdk((c=a.a.a,a.b[0],c));break;case 2:Udk(a.a.a,a.b[0]);break;case 3:a.a.a.H.KF();break;case 4:a.a.a.H.LF();break;case 5:Zdk(a.a.a);break;case 6:$dk((b=a.a.a,a.b[0],b));break;case 7:a.a.a.H.NF();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\n$$c(6874,31,{},nek);_.Bt=function pek(a){var b;gpf((b=this,a,b).a.c,new brf,false)};_.At=function oek(a){vHf(this.b,a.a?a.a.c:a.d)};var mic=qHd(6874);$$c(454,1,RHn);_.xm=function Pfk(){Mfk((new Qfk(this)).a)};$$c(6416,1,Khn,Qfk);_.zm=function Rfk(){Mfk(this.a)};var Lic=qHd(6416);H8m(Gl)(16);\n//# sourceURL=rstudio-16.js\n")
