$wnd.rstudio.runAsyncCallback16("function HCk(a){var b;Dvn[b=++Evn]=HCk;this.a=(Fvn[b]=Pvn,a);Evn=b-1}\nfunction eBk(a,b){var c;Dvn[c=++Evn]=eBk;this.a=(Fvn[c]=fJn,a);this.b=b;Kne.call(this);Evn=c-1}\nfunction GAk(a){var b,c;Dvn[c=++Evn]=GAk;b=$$f(new _$f(0,(Gvn='Closing Presentation...',Fvn[c]=oMn,Gvn)));cWh((Fvn[c]=fJn,a).j,new eBk(a,b));Evn=c-1}\nfunction cWh(a,b){var c;Dvn[c=++Evn]=cWh;Y$h((Fvn[c]=$Jp,a),qXo,'close_presentation_pane',(Fvn[c]=Q8o,new iH),(Gvn=(Fvn[c]=$Jp,b),Fvn[c]=R8o,Gvn));Evn=c-1}\nfunction JAk(a,b){var c;Dvn[c=++Evn]=JAk;(Fvn[c]=oJn,a).a=b;WBk((Fvn[c]=pCn,a).n,FAk(a,(Gvn=null,Fvn[c]=ULn,Gvn)),(Gvn=(Fvn[c]=Hvn,(Fvn[c]=pCn,a).a.file_path),Fvn[c]=pCn,Gvn));Evn=c-1}\nfunction RAk(a){var b;Dvn[b=++Evn]=RAk;Onf('Opening Presentation...',(Fvn[b]=$Dn,dBd()));aIf((Fvn[b]=Q7n,(Fvn[b]=exn,a).c),new XJf,(Gvn=false,Fvn[b]=own,Gvn));Evn=b-1}\nfunction LAk(a,b){var c;Dvn[c=++Evn]=LAk;(Fvn[c]=Uvn,(Fvn[c]=uzn,b).slide_index)==0&&XPi((Fvn[c]=bxn,a).n);Fvn[c]=oJn,(Fvn[c]=qxn,a).a=b;WBk((Fvn[c]=pCn,(Fvn[c]=qxn,a).n),FAk((Fvn[c]=qxn,a),(Gvn=null,Fvn[c]=ULn,Gvn)),(Gvn=(Fvn[c]=Hvn,(Fvn[c]=pCn,(Fvn[c]=qxn,a).a).file_path),Fvn[c]=pCn,Gvn));Evn=c-1}\nfunction QAk(a){var b,c;Dvn[c=++Evn]=QAk;(Fvn[c]=Qwn,(Fvn[c]=lBn,a).G).OH();!(Fvn[c]=sAn,!(Fvn[c]=NIn,a).a)&&(Fvn[c]=Vvn,(Fvn[c]=Ivn,a).a.active)&&(b=Kke((Gvn=(Fvn[c]=eHn,ph((Gvn=(Fvn[c]=rAn,(Fvn[c]=PBn,a).n.d),Fvn[c]=Nwn,Gvn)).contentWindow),Fvn[c]=rAn,Gvn)),(Fvn[c]=PBn,!(!dOd(Fdo,(Fvn[c]=dBn,b))&&!dOd('javascript:void(0)',(Fvn[c]=$Dn,b)))))&&JAk((Fvn[c]=kxn,a),a.a);Evn=c-1}\nfunction DCk(b){var c,d,e,f;Dvn[e=++Evn]=DCk;try{if((Fvn[e]=Svn,b).c<0){f=true;return}if(Fvn[e]=bAn,!(Fvn[e]=Zwn,b).a.a){Fvn[e]=fwn,(Fvn[e]=fwn,b).a.a=rDk((Fvn[e]=Oxn,b.a.b.a));GKi((Fvn[e]=lxn,b).a,b.a.a)}switch((Fvn[e]=$xn,b).c){case 1:GAk((d=(Fvn[e]=hwn,b).a.a,b.b[0],d));break;case 2:LAk((Fvn[e]=Jwn,b).a.a,b.b[0]);break;case 3:(Fvn[e]=bwn,(Fvn[e]=qwn,b).a.a.G).MH();break;case 4:(Fvn[e]=Nzn,(Fvn[e]=ryn,b).a.a.G).NH();break;case 5:QAk((Fvn[e]=syn,b).a.a);break;case 6:RAk((c=(Fvn[e]=XAn,b).a.a,b.b[0],c));break;case 7:(Fvn[e]=Own,(Fvn[e]=ODn,b).a.a.G).PH();}}catch(a){a=i2c(a);Evn=(Fvn[e]=hxn,e);throw j2c(a)}finally{(Fvn[e]=Azn,b).c<=0&&b.b[0]!=null&&b.b[0].zm();f&&(Evn=e-1)}Evn=e-1}\nL2c(6902,31,{},eBk);_.xu=function gBk(a){var b,c;Dvn[c=++Evn]=gBk;aIf((Fvn[c]=Q7n,(Fvn[c]=gCn,(Fvn[c]=jLn,b=this,a,b).a).c),new XJf,(Gvn=false,Fvn[c]=own,Gvn));Evn=c-1};_.wu=function fBk(a){var b;Dvn[b=++Evn]=fBk;q$f((Fvn[b]=dLn,this.b),(Gvn=(Fvn[b]=mxn,a.a)?(Fvn[b]=Wvn,(Fvn[b]=hwn,(Fvn[b]=dLn,a).a).c):(Fvn[b]=Iwn,(Fvn[b]=dLn,a).d),Fvn[b]=dLn,Gvn));Evn=b-1};var Jlc=tMd(6902);L2c(452,1,vKo);_.xm=function GCk(){var a;Dvn[a=++Evn]=GCk;DCk((Fvn[a]=twn,(new HCk((Gvn=this,Fvn[a]=Pvn,Gvn))).a));Evn=a-1};L2c(6444,1,Uco,HCk);_.zm=function ICk(){var a;Dvn[a=++Evn]=ICk;DCk((Fvn[a]=twn,this.a));Evn=a-1};var gmc=tMd(6444);Cvn(Kl)(16);\n//# sourceURL=rstudio-16.js\n")
